@@ -23,6 +23,7 @@ use crate::{
     rustc_data_structures::stable_hasher::StableHasher,
     sync::{Lock, LockGuard, Lrc, MappedLockGuard},
 };
+use once_cell::sync::Lazy;
 #[cfg(feature = "sourcemap")]
 use sourcemap::SourceMapBuilder;
 use std::{
@@ -30,12 +31,14 @@ use std::{
     cmp::{max, min},
     env, fs,
     hash::Hash,
-    io::{self, Read},
+    io,
     path::{Path, PathBuf},
     sync::atomic::{AtomicUsize, Ordering::SeqCst},
 };
 use tracing::debug;
 
+static CURRENT_DIR: Lazy<Option<PathBuf>> = Lazy::new(|| env::current_dir().ok());
+
 // _____________________________________________________________________________
 // SourceFile, MultiByteChar, FileName, FileLines
 //
@@ -64,14 +67,12 @@ impl FileLoader for RealFileLoader {
         if path.is_absolute() {
             Some(path.to_path_buf())
         } else {
-            env::current_dir().ok().map(|cwd| cwd.join(path))
+            CURRENT_DIR.as_ref().map(|cwd| cwd.join(path))
         }
     }
 
     fn read_file(&self, path: &Path) -> io::Result<String> {
-        let mut src = String::new();
-        fs::File::open(path)?.read_to_string(&mut src)?;
-        Ok(src)
+        fs::read_to_string(path)
     }
 }
 
